from PyQt5.QtCore import QObject, pyqtSignal
from PyQt5.QtWidgets import QComboBox, QApplication

from astra_installer.settings.manager import SettingsManager
from astra_installer_qt.components_manager import ComponentsManager

translate = QApplication.translate


class ModeManager(QObject):
    locale_changed = pyqtSignal()

    def __init__(self, combobox: QComboBox,
                 cmanager: ComponentsManager) -> None:
        super().__init__()
        self.combobox = combobox
        self.cmanager = cmanager
        self.selected_index = 0
        self.setup()

    def setup(self) -> None:
        self.combobox.activated.connect(self.apply)
        self.add_modes()

    def add_modes(self) -> None:
        self.combobox.clear()
        self.selected_index = 0
        for index, mode in enumerate(SettingsManager.mode.modes):
            self.combobox.addItem(translate('mode', mode.name), mode)
            if mode.selected:
                self.selected_index = index
        self.combobox.setCurrentIndex(self.selected_index)

    def apply(self) -> None:
        selected_mode = self.combobox.currentData()
        for mode in SettingsManager.mode.modes:
            mode.selected = True if mode.ident == selected_mode.ident else False
        self.cmanager.update_components(selected_mode.features)

    def retranslate(self, locale: str) -> None:
        self.add_modes()
        self.apply()
